from setuptools import setup, find_packages
import os

version = "1.7"

setup(name="tno.euphorie",
      version=version,
      description="TNO specific extensions for Euphorie",
      long_description=open("README.txt").read() + "\n" +
                       open(os.path.join("docs", "HISTORY.txt")).read(),
      classifiers=[
        "Framework :: Plone",
        "Programming Language :: Python",
        ],
      keywords="Euphorie OIRAT RIE",
      author="Wichert Akkerman",
      author_email="wichert@simplon.biz",
      url="http://instrumenten.rie.nl/",
      license="GPL",
      packages=find_packages(exclude=["ez_setup"]),
      namespace_packages=["tno"],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          "Euphorie >=2.1",
          "plone.browserlayer",
          "five.grok",
          "plone.directives.form",
          "plone.namedfile",
          "setuptools",
          "z3c.form",
          "zope.i18nmessageid",
      ],
      tests_require = [
          "Euphorie [tests]",
      ],
      extras_require = {
        "tests" : [ "Euphorie [tests]",
                  ],
      },
      )



from five import grok
from euphorie.client.survey import SurveyPublishTraverser
from euphorie.client.survey import ActionPlanReportView
from euphorie.client.survey import ActionPlanReportDownload
from tno.euphorie.interfaces import ITnoIdentificationPhaseSkinLayer
from tno.euphorie.interfaces import ITnoEvaluationPhaseSkinLayer
from tno.euphorie.interfaces import ITnoActionPlanPhaseSkinLayer
from tno.euphorie.interfaces import ITnoReportPhaseSkinLayer
from tno.euphorie.model import DutchCompany

grok.templatedir("templates")

class TnoSurveyPublishTraverser(SurveyPublishTraverser):
    phases = {
            "identification": ITnoIdentificationPhaseSkinLayer,
            "evaluation": ITnoEvaluationPhaseSkinLayer,
            "actionplan": ITnoActionPlanPhaseSkinLayer,
            "report": ITnoReportPhaseSkinLayer,
            }


class TnoActionPlanReportView(ActionPlanReportView):
    grok.layer(ITnoReportPhaseSkinLayer)
    grok.name("view")
    grok.template("report_actionplan")

    def update(self):
        super(TnoActionPlanReportView, self).update()
        if self.session.dutch_company is None:
            self.session.dutch_company=DutchCompany()


class TnoActionPlanReportDownload(ActionPlanReportDownload):
    grok.layer(ITnoReportPhaseSkinLayer)
    grok.name("download")
    grok.template("report_actionplan")

    def update(self):
        super(TnoActionPlanReportDownload, self).update()
        if self.session.dutch_company is None:
            self.session.dutch_company=DutchCompany()

